# Discord.py Toolbox
## Made by TheWever

Thank you for using dpy-toolbox. This is just an early alpha. New features can be requested in my [discord](https://discord.gg/rnEwUJ7Fhc). You might report bugs in the [issue tracker](https://github.com/TheWever/dpy-toolbox/issues). You can find all [examples](https://github.com/TheWever/dpy-toolbox/tree/main/examples) in the github. Make sure to check out the [documentation](https://dpy-toolbox.rtfd.io/).

-TheWever